# py_ez_wikidata
Mapping for Wikidata allows creation of wikidata entries from dicts

[![Join the discussion at https://github.com/WolfgangFahl/py_ez_wikidata/discussions](https://img.shields.io/github/discussions/WolfgangFahl/py_ez_wikidata)](https://github.com/WolfgangFahl/py_ez_wikidata/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/py_ez_wikidata)](https://pypi.org/project/py_ez_wikidata/)
[![Github Actions Build](https://github.com/WolfgangFahl/py_ez_wikidata/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/py_ez_wikidata/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/py_ez_wikidata.svg)](https://pypi.python.org/pypi/py_ez_wikidata/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/py_ez_wikidata.svg)](https://github.com/WolfgangFahl/py_ez_wikidata/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/py_ez_wikidata.svg)](https://github.com/WolfgangFahl/py_ez_wikidata/issues/?q=is%3Aissue+is%3Aclosed)
[![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/py_ez_wikidata/)
[![License](https://img.shields.io/github/license/WolfgangFahl/py_ez_wikidata.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Docs
[Wiki](https://wiki.bitplan.com/index.php/Py_ez_wikidata)
